==> noahs-2.1.5.tar.gz: noahs/src/Plugin/Widget/WidgetNoahsColumn.php <==
<?php

namespace Drupal\noahs_page_builder\Plugin\Widget;

use Drupal\noahs_page_builder\Annotation\WidgetPlugin;
use Drupal\noahs_page_builder\Plugin\Widget\WidgetBase;
use Drupal\image\Entity\ImageStyle;
/**
 * @WidgetPlugin(
 *   id = "noahs_column",
 *   label = @Translation("Column")
 * )
 */
class WidgetNoahsColumn extends WidgetBase{

	public function data(){
		return [
			'icon' => 'icon-column',
			'title' => 'Column',
			'description' => 'Description'
		];
	}

	public function renderForm(){
		$form = [];

		// Section Content
		$form['section_content'] = [
			'type' => 'tab',
			'title' =>  t('Content')
		];

		$form['column_width'] =[
			'type'    => 'noahs_width',
			'title'   => ('Colum Width'),
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'width', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		$form['innver_column_width'] =[
			'type'    => 'noahs_width',
			'title'   => ('Inner Width'),
			'style_type' => 'style',
			'style_selector' => '.widget-wrapper', 
			'style_css' => 'max-width', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		$form['section_height'] = [
			'type'    => 'select',
			'title'   => t('Column height'),
			'tab' => 'section_content',
			'style_type' => 'class',
			'style_selector' => 'widget', 
			'options' => [
				'' => t('default'),
				'full-height' => t('Full height'),
				'min-height' => t('Min Height'),
			]
		];
		$form['section_min_height'] = [
			'type'    => 'text',
			'title'   => t('Min height'),
			'tab' => 'section_content',
			'placeholder'     => t('Min height'),
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'min-height', 
			'state' => [
				'visible' => [
					'section_height' => ['value' => 'min-height'],
				  ],
			]
		];
		$form['vertical_align'] = [
			'type'    => 'select',
			'title'   => t('Vertical Align'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.widget-wrapper', 
			'style_css' => 'align-items', 
			'responsive' => true,
			'options' => [
				'' => t('Center'),
				'flex-start' => t('Top'),
				'flex-end' => t('Bottom'),
			]
		];

		$form['column_elements_inline'] = [
			'type'    => 'select',
			'title'   => t('Elements orientation'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner', 
			'style_css' => 'flex-direction',
			'responsive' => true,
			'options' => [
				'' => 'Por defecto (one under the other)',
				'column-reverse' => 'Column Reverse',
				'row' => 'Inline',
				'row-reverse' => 'Inline Reverse',
				'revert' => 'Revert',
				'unset' => 'Unset',
			]
		];

		$form['column_elements_wrap'] = [
			'type'    => 'select',
			'title'   => t('Elements wrap'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner', 
			'style_css' => 'flex-wrap',
			'responsive' => true,
			'options' => [
				'' => t('Por defecto (wrap)'),
				'nowrap' => t('No Wrap'),
			]
		];
		$form['horizontal_align_structures'] = [
			'type'    => 'select',
			'title'   => t('Distribution'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner',
			'style_css' => 'justify-content',
			'responsive' => true,
			'options' => [
				'' => 'Por defecto',
				'flex-start' => 'Start',
				'center' => 'Center',
				'flex-end' => 'End',
				'space-between' => 'Space Betwenn',
				'space-around' => 'Space Around',
				'space-evenly' => 'Space Evenly'
			]
		];
		$form['horizontal_align'] = [
			'type'    => 'select',
			'title'   => t('Horizontal Align'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'text-align',
			'responsive' => true,
			'options' => [
				'' => 'Por defecto',
				'left' => 'Left',
				'center' => 'Center',
				'right' => 'Right',
			]
		];

		$form['elements_gap'] =[
			'type'    => 'text',
			'title'   => ('Element Space'),
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner ', 
			'style_css' => 'gap', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		  
		// Section Styles
		$form['section_styles'] = [
			'type' => 'tab',
			'title' => t('Styles')
		];
		$form['bg_color'] = [
			'type'     => 'noahs_color',
			'title'    => ('Background Color'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_css' => 'background-color', 
			'style_selector' => 'widget', 
		];
		
		$form['bg_image'] = [
			'type'     => 'noahs_background_image',
			'title'    => ('Background Image'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_hover' => true,
			'responsive' => true,
		];
		
		$form['group_bg_animate'] = [
			'type' => 'group',
			'tab' => 'section_styles',
			'title' => t('Background Animate')
		];

		$form['background_parallax'] = [
			'type'    => 'number',
			'title'   => ('Parallax'),
			'style_selector' => 'widget', 
			'style_type' => 'attribute',
			'attribute_type' => 'data-background-parallax', 
			'tab' => 'section_styles',
			'group' => 'group_bg_animate',
			'wrapper' => false,
		  ];

		$form['bg_gradient'] = [
			'type'     => 'noahs_background_gradient',
			'title'    => ('Background Gradient'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'responsive' => true,
		];
		$form['video_background'] = [
			'type'     => 'noahs_video_background',
			'title'    => ('Video Background'),
			'tab'     => 'section_styles',
			'append' => 'widget',
		];
		$form['font'] = [
			'type'        => 'noahs_font',
			'title'       => t('Font'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'responsive' => true,
		  ];


		return $form;
	}

	public function template( $settings,  $content = '' ) {

		$twig = \Drupal::service('twig');
    
		$element_content = $twig->render(NOAHS_PAGE_BUILDER_PATH . '/templates/widgets/noahs_column.twig', [
			'settings' => $settings,
			'content' => $content
		]);
		return $element_content;
	}
	
	public function renderContent($element, $content = null) {
		return $this->wrapper($element, $this->template($element, $content), $element);
	}
	
}

==> noahs-2.1.6.tar.gz: noahs/src/Plugin/Widget/WidgetNoahsColumn.php <==
<?php

namespace Drupal\noahs_page_builder\Plugin\Widget;

use Drupal\noahs_page_builder\Annotation\WidgetPlugin;
use Drupal\noahs_page_builder\Plugin\Widget\WidgetBase;
use Drupal\image\Entity\ImageStyle;
/**
 * @WidgetPlugin(
 *   id = "noahs_column",
 *   label = @Translation("Column")
 * )
 */
class WidgetNoahsColumn extends WidgetBase{

	public function data(){
		return [
			'icon' => 'icon-column',
			'title' => 'Column',
			'description' => 'Description'
		];
	}

	public function renderForm(){
		$form = [];

		// Section Content
		$form['section_content'] = [
			'type' => 'tab',
			'title' =>  t('Content')
		];

		$form['column_width'] =[
			'type'    => 'noahs_width',
			'title'   => ('Colum Width'),
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'width', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		$form['innver_column_width'] =[
			'type'    => 'noahs_width',
			'title'   => ('Inner Width'),
			'style_type' => 'style',
			'style_selector' => '.widget-wrapper', 
			'style_css' => 'max-width', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		$form['section_height'] = [
			'type'    => 'select',
			'title'   => t('Column height'),
			'tab' => 'section_content',
			'style_type' => 'class',
			'style_selector' => 'widget', 
			'options' => [
				'' => t('default'),
				'full-height' => t('Full height'),
				'min-height' => t('Min Height'),
			]
		];
		$form['section_min_height'] = [
			'type'    => 'text',
			'title'   => t('Min height'),
			'tab' => 'section_content',
			'placeholder'     => t('Min height'),
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'min-height', 
			'state' => [
				'visible' => [
					'section_height' => ['value' => 'min-height'],
				  ],
			]
		];
		$form['vertical_align'] = [
			'type'    => 'select',
			'title'   => t('Vertical Align'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.widget-wrapper', 
			'style_css' => 'align-items', 
			'responsive' => true,
			'options' => [
				'' => t('Center'),
				'flex-start' => t('Top'),
				'flex-end' => t('Bottom'),
			]
		];

		$form['column_elements_inline'] = [
			'type'    => 'select',
			'title'   => t('Elements orientation'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner', 
			'style_css' => 'flex-direction',
			'responsive' => true,
			'options' => [
				'column' => 'Por defecto (one under the other)',
				'column-reverse' => 'Column Reverse',
				'row' => 'Inline',
				'row-reverse' => 'Inline Reverse',
				'revert' => 'Revert',
				'unset' => 'Unset',
			]
		];

		$form['column_elements_wrap'] = [
			'type'    => 'select',
			'title'   => t('Elements wrap'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner', 
			'style_css' => 'flex-wrap',
			'responsive' => true,
			'options' => [
				'' => t('Por defecto (wrap)'),
				'nowrap' => t('No Wrap'),
			]
		];
		$form['horizontal_align_structures'] = [
			'type'    => 'select',
			'title'   => t('Distribution'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner',
			'style_css' => 'justify-content',
			'responsive' => true,
			'options' => [
				'' => 'Por defecto',
				'flex-start' => 'Start',
				'center' => 'Center',
				'flex-end' => 'End',
				'space-between' => 'Space Betwenn',
				'space-around' => 'Space Around',
				'space-evenly' => 'Space Evenly'
			]
		];
		$form['horizontal_align'] = [
			'type'    => 'select',
			'title'   => t('Horizontal Align'),
			'tab' => 'section_content',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_css' => 'text-align',
			'responsive' => true,
			'options' => [
				'' => 'Por defecto',
				'left' => 'Left',
				'center' => 'Center',
				'right' => 'Right',
			]
		];

		$form['elements_gap'] =[
			'type'    => 'text',
			'title'   => ('Element Space'),
			'style_type' => 'style',
			'style_selector' => '.noahs_page_builder-column--content-inner ', 
			'style_css' => 'gap', 
			'tab' => 'section_content',
			'responsive' => true,
			'placeholder' => 'use as 10%, 100px, 100vw...',
		];
		  
		// Section Styles
		$form['section_styles'] = [
			'type' => 'tab',
			'title' => t('Styles')
		];
		$form['bg_color'] = [
			'type'     => 'noahs_color',
			'title'    => ('Background Color'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_css' => 'background-color', 
			'style_selector' => 'widget', 
		];
		
		$form['bg_image'] = [
			'type'     => 'noahs_background_image',
			'title'    => ('Background Image'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'style_hover' => true,
			'responsive' => true,
		];
		
		$form['group_bg_animate'] = [
			'type' => 'group',
			'tab' => 'section_styles',
			'title' => t('Background Animate')
		];

		$form['background_parallax'] = [
			'type'    => 'number',
			'title'   => ('Parallax'),
			'style_selector' => 'widget', 
			'style_type' => 'attribute',
			'attribute_type' => 'data-background-parallax', 
			'tab' => 'section_styles',
			'group' => 'group_bg_animate',
			'wrapper' => false,
		  ];

		$form['bg_gradient'] = [
			'type'     => 'noahs_background_gradient',
			'title'    => ('Background Gradient'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'responsive' => true,
		];
		$form['video_background'] = [
			'type'     => 'noahs_video_background',
			'title'    => ('Video Background'),
			'tab'     => 'section_styles',
			'append' => 'widget',
		];
		$form['font'] = [
			'type'        => 'noahs_font',
			'title'       => t('Font'),
			'tab'     => 'section_styles',
			'style_type' => 'style',
			'style_selector' => 'widget', 
			'responsive' => true,
		  ];


		return $form;
	}

	public function template( $settings,  $content = '' ) {

		$twig = \Drupal::service('twig');
    
		$element_content = $twig->render(NOAHS_PAGE_BUILDER_PATH . '/templates/widgets/noahs_column.twig', [
			'settings' => $settings,
			'content' => $content
		]);
		return $element_content;
	}
	
	public function renderContent($element, $content = null) {
		return $this->wrapper($element, $this->template($element, $content), $element);
	}
	
}
